'use strict';

var _TraverseImport = require('../TraverseImport');

var _TraverseImport2 = _interopRequireDefault(_TraverseImport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Remove padding from a string.
function unpad(str) {
  var lines = str.split('\n');
  var m = lines[1] && lines[1].match(/^\s+/);
  if (!m) {
    return str;
  }
  var spaces = m[0].length;
  return lines.map(function (line) {
    return line.slice(spaces);
  }).join('\n').trim();
}

describe('PlatformLoader.traverseImport', function () {
  it('isWeex true', function () {
    var _traverseImport = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex } from "universal-env";'),
        code = _traverseImport.code;

    expect(code).toBe('const isWeex = true;');
  });

  it('isWeex as iw', function () {
    var _traverseImport2 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex as iw } from "universal-env";'),
        code = _traverseImport2.code;

    var expected = unpad('\n      const iw = true;\n      const isWeex = true;\n    ');

    expect(code).toBe(expected);
  });

  it('isWeex and isWeb', function () {
    var _traverseImport3 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport3.code;

    var expected = unpad('\n      const isWeb = false;\n      const isWeex = true;\n    ');

    expect(code).toBe(expected);
  });

  it('isWeb true', function () {
    var _traverseImport4 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, 'import { isWeb } from "universal-env";'),
        code = _traverseImport4.code;

    expect(code).toBe('const isWeb = true;');
  });

  it('skin other module', function () {
    var _traverseImport5 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, unpad('\n        import { isWeb } from "universal-env";\n        import { XXX } from "universal-other";\n      ')),
        code = _traverseImport5.code;

    var expected = unpad('\n      const isWeb = true;\n\n      import { XXX } from "universal-other";\n    ');

    expect(code).toBe(expected);
  });

  it('not platform specified', function () {
    var _traverseImport6 = (0, _TraverseImport2.default)({ name: 'universal-env' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport6.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });

  it('unknown platform', function () {
    var _traverseImport7 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'xxxx' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport7.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });

  it('unknown platform and unknown name', function () {
    var _traverseImport8 = (0, _TraverseImport2.default)({ name: 'universal-xxx' }, 'import { isWeex, isWeb } from "universal-env";'),
        code = _traverseImport8.code;

    expect(code).toBe('import { isWeex, isWeb } from "universal-env";');
  });
});