'use strict';

var _TraverseImport = require('../TraverseImport');

var _TraverseImport2 = _interopRequireDefault(_TraverseImport);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Remove padding from a string.
function unpad(str) {
  var lines = str.split('\n');
  var m = lines[1] && lines[1].match(/^\s+/);
  if (!m) {
    return str;
  }
  var spaces = m[0].length;
  return lines.map(function (line) {
    return line.slice(spaces);
  }).join('\n').trim();
}

describe('PlatformLoader.traverseImport work on CommonJS', function () {
  it('isWeex true', function () {
    var _traverseImport = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, 'const env = require("universal-env");'),
        code = _traverseImport.code;

    var expected = unpad('\n      const env = {\n        isWeex: true,\n        isWeb: false,\n        isNode: false,\n        isReactNative: false\n      };\n    ');

    expect(code).toBe(expected);
  });

  it('isWeex as iw', function () {
    var _traverseImport2 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'weex' }, unpad('\n        const env = require("universal-env");\n        const iw = env.isWeex;\n      ')),
        code = _traverseImport2.code;

    var expected = unpad('\n      const env = {\n        isWeex: true,\n        isWeb: false,\n        isNode: false,\n        isReactNative: false\n      };\n      const iw = env.isWeex;\n    ');

    expect(code).toBe(expected);
  });

  it('skin other module', function () {
    var _traverseImport3 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'web' }, unpad('\n        const xxx = require("universal-env").xxx;\n      ')),
        code = _traverseImport3.code;

    var expected = unpad('\n      const xxx = {\n        isWeex: false,\n        isWeb: true,\n        isNode: false,\n        isReactNative: false\n      }.xxx;\n    ');

    expect(code).toBe(expected);
  });

  it('not platform specified', function () {
    var _traverseImport4 = (0, _TraverseImport2.default)({ name: 'universal-env' }, 'const env = require("universal-env");'),
        code = _traverseImport4.code;

    var expected = 'const env = require("universal-env");';

    expect(code).toBe(expected);
  });

  it('unknown platform', function () {
    var _traverseImport5 = (0, _TraverseImport2.default)({ name: 'universal-env', platform: 'xxxx' }, 'const env = require("universal-env");'),
        code = _traverseImport5.code;

    var expected = 'const env = require("universal-env");';

    expect(code).toBe(expected);
  });

  it('unknown platform and unknown name', function () {
    var _traverseImport6 = (0, _TraverseImport2.default)({ name: 'universal-xxx' }, 'const env = require("universal-env");'),
        code = _traverseImport6.code;

    expect(code).toBe('const env = require("universal-env");');
  });
});